==> enterprisemodules-ovm_config-1.0.5.tar.gz: enterprisemodules-ovm_config-1.0.5/lib/puppet/type/ovm_server.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/ovm/core'

module Puppet
  # Type responsible for managing of ovm servers available for manager
  Type.newtype(:ovm_server) do
    include Puppet_X::EnterpriseModules::Ovm::Type

    desc <<-EOD
    This resource allows you manage VM Server. Before running server
    manifest make sure you have present Server Pools in the type of
    ovm_server_pool.

    To discover and setup server run Puppet manifest.
    Here is an example on how to use this:

        ovm_server { 'default/mypool1/ovmserver1.example.com':
          ensure       => 'present',
          password     => 'vagrant'
          description  => 'Server 1',
          ip_address   => '172.28.128.19',
          ntp_servers  => ['172.28.128.3'],
          server_roles => ['VM'],
        }

    EOD

    restfull_type('Server')

    ensurable

    parameter :id
    parameter :manager_name
    parameter :name
    parameter :server_pool_name
    parameter :server_name
    parameter :password

    property  :description
    property  :ip_address
    property  :ntp_servers
    property  :protected
    property  :server_roles
    property  :ovm_tags

    add_title_attributes(:server_pool_name, :server_name) { /(.+)\/(.+)/ }

    def on_create
      discover
      update_properties
      add_to_pool
    end

    def create_payload
      data = server_data(server_id).merge(super)
      data.delete('password')
      data.merge!(
        'serverPoolId' => server_pool_reference,
        'id'           => server_reference
      )
      data
    end

    # This block executes parameters after the server is discovered in the on_create block
    def update_properties
      path = "#{create_path}/#{server_id}"
      with_manager_connection do |connection|
        connection.validated(:put, path, create_payload)
      end
    end

    before_destroy do
      remove_from_pool
    end

    private

    def remove_from_pool
      parameters    =  URI.encode_www_form('serverPoolId' => server_pool_id)
      Puppet.debug "Removing server #{server_name} from server pool #{server_pool_name}."
      with_manager_connection do |connection|
        connection.validated(:put, "#{::Puppet_X::EnterpriseModules::Ovm::Type::BASE_PATH}/ServerPool/#{server_pool_id}/removeServer?#{parameters}", server_reference)
      end
    end

    def discover
      fail "#{path}: Password required parameter when server needs to be discovered" if password.nil?
      path = create_path + "/discover?serverName=#{ip_address}&takeOwnershipIfUnowned=true"
      Puppet.debug "Discover server #{server_name}..."
      with_manager_connection do |connection|
        connection.validated(:post, path, password, true)
      end
    end

    def add_to_pool
      path = "#{::Puppet_X::EnterpriseModules::Ovm::Type::BASE_PATH}/ServerPool/#{server_pool_id}/addServer"
      Puppet.debug "Add server #{server_name} from server pool #{server_pool_name}."
      with_manager_connection do |connection|
        connection.validated(:put, path, server_reference)
      end
    end
  end
end

==> enterprisemodules-ovm_config-1.1.0.tar.gz: enterprisemodules-ovm_config-1.1.0/lib/puppet/type/ovm_server.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/ovm/core'

#
# Type responsible for managing of ovm servers available for manager.
#
module Puppet
  Type.newtype(:ovm_server) do
    include Puppet_X::EnterpriseModules::Ovm::Type

    desc <<-DOCS
    This resource allows you manage VM Server. Before running server
    manifest make sure you have present Server Pools in the type of
    ovm_server_pool.

    To discover and setup server run Puppet manifest.
    Here is an example on how to use this:

        ovm_server { 'default/mypool1/ovmserver1.example.com':
          ensure       => 'present',
          password     => 'vagrant'
          description  => 'Server 1',
          ip_address   => '172.28.128.19',
          ntp_servers  => ['172.28.128.3'],
          server_roles => ['VM'],
        }

    DOCS

    restfull_type('Server')

    ensurable

    parameter :id
    parameter :manager_name
    parameter :name
    parameter :server_pool_name
    parameter :server_name
    parameter :password

    property  :description
    property  :ip_address
    property  :ntp_servers
    property  :protected
    property  :server_roles
    property  :ovm_tags

    add_title_attributes(:server_pool_name, :server_name) { %r((.+)/(.+)) }

    def on_create
      discover
      update_properties
      add_to_pool
    end

    def create_payload
      data = server_data(server_id).merge(super)
      data.delete('password')
      data['serverPoolId'] = server_pool_reference
      data['id'] = server_reference
      data
    end

    # This block executes parameters after the server is discovered in the on_create block
    def update_properties
      path = "#{create_path}/#{server_id}"
      with_manager_connection do |connection|
        connection.validated(:put, path, create_payload)
      end
    end

    before_destroy do
      remove_from_pool
    end

    private

    def remove_from_pool
      parameters = URI.encode_www_form('serverPoolId' => server_pool_id)
      Puppet.debug "Removing server #{server_name} from server pool #{server_pool_name}."
      with_manager_connection do |connection|
        connection.validated(:put, "#{::Puppet_X::EnterpriseModules::Ovm::Dict::BASE_PATH}/ServerPool/#{server_pool_id}/removeServer?#{parameters}", server_reference)
      end
    end

    def discover
      fail "#{path}: Password required parameter when server needs to be discovered" if password.nil?

      path = create_path + "/discover?serverName=#{ip_address}&takeOwnershipIfUnowned=true"
      Puppet.debug "Discover server #{server_name}..."
      with_manager_connection do |connection|
        connection.validated(:post, path, password, true)
      end
    end

    def add_to_pool
      path = "#{::Puppet_X::EnterpriseModules::Ovm::Dict::BASE_PATH}/ServerPool/#{server_pool_id}/addServer"
      Puppet.debug "Add server #{server_name} from server pool #{server_pool_name}."
      with_manager_connection do |connection|
        connection.validated(:put, path, server_reference)
      end
    end
  end
end
